@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999 by David I. Bell
+ * Copyright (c) 2002 by David I. Bell
  * Permission is granted to use, distribute, or modify this source,
  * provided that this copyright notice remains intact.
  *
@@ -9,7 +9,7 @@
  * uncompress the files.
  */
 
-#ifdef	HAVE_GZIP
+#if	HAVE_GZIP
 
 
 #include <sys/types.h>
